@@ -21,13 +21,15 @@ edit.nb <- function(name, coords, polys=NULL, bbs=NULL, ...) {
 	points(x, y)
 	finished <- "n"
 	deletions <- NULL
+	additions <- NULL
 	while (finished == "n") {
 		cat("Identifying contiguity for deletion ...\n")
 		cand <- identify(x, y, n=2)
+		lines(x[cand], y[cand], col="red")
+
 		if (.Platform$OS.type == "windows") bringToTop(-1)
 		if ((cand[2] %in% nb[[cand[1]]]) && (cand[1] %in% nb[[cand[2]]])) {
-			lines(x[cand], y[cand], col="red")
-			delete <- readline("Delete this line (y/n) ")
+						delete <- readline("Delete this line (y/n) ")
 			if (delete != "y") delete <- "n"
 			else {
 				deletions <- c(deletions, paste(cand,
@@ -46,7 +48,7 @@ edit.nb <- function(name, coords, polys=NULL, bbs=NULL, ...) {
 					cand[1], "and", cand[2], "\n")
 
  			}
-						plot.new()
+			plot.new()
 	        	plot.window(xlim = xlim, ylim = ylim, "", asp=1)
 			if (!is.null(polys) && !is.null(bbs))
 				plotpolys(polys,bbs, border="grey", add=T)
@@ -58,12 +60,40 @@ edit.nb <- function(name, coords, polys=NULL, bbs=NULL, ...) {
 			}
 			points(x, y)
 		} else {
-			cat("No contiguity between chosen points\n")
+			if (length(cand == 2)) {
+				cat("No contiguity between chosen points\n")
+				addcont <- readline("Add contiguity? (y/n) ")
+				if (addcont != "y") addcont <- "n"
+				if (addcont == "y") {
+					nb[[cand[1]]] <-
+					sort(unique(c(nb[[cand[1]]], cand[2])))
+					nb[[cand[2]]] <-
+					sort(unique(c(nb[[cand[2]]], cand[1])))
+					cat("added contiguity between point",
+					cand[1], "and", cand[2], "\n")
+					additions <- c(additions, paste(cand,
+					collapse="-"))
+
+				}
+				plot.new()
+	        		plot.window(xlim = xlim, ylim = ylim, "", asp=1)
+				if (!is.null(polys) && !is.null(bbs))
+				plotpolys(polys,bbs, border="grey", add=T)
+				for (i in 1:n) {
+	        			inb <- nb[[i]]
+	        			for (j in inb)
+						lines(c(x[i], x[j]),
+							c(y[i], y[j]),
+							col="black")
+				}
+				points(x, y)
+			}
 		}
 		finished <- readline("Finished yet? (y/n) ")
 		if (finished != "y") finished <- "n"
 	}
 	attributes(nb) <- list(deleted=deletions)
+	attr(nb, "added") <- additions
 	attr(nb, "region.id") <- row.names
 	class(nb) <- "nb"
 	invisible(nb)
