@@ -1,4 +1,5 @@
-plot.nb <- function(nb, coords, col="black", add=FALSE) {
+plot.nb <- function(x, coords, col="black", points=TRUE, add=FALSE, ...) {
+	nb <- x
 	x <- coords[,1]
 	y <- coords[,2]
 	n <- length(nb)
@@ -6,13 +7,13 @@ plot.nb <- function(nb, coords, col="black", add=FALSE) {
 	ylim <- range(y)
 	if (!add) {
 		plot.new()
-        	plot.window(xlim = xlim, ylim = ylim, "", asp=1)
+        	plot.window(xlim = xlim, ylim = ylim, log="", asp=1)
 	}
 	for (i in 1:n) {
         	inb <- nb[[i]]
         	for (j in inb)
 			lines(c(x[i], x[j]), c(y[i], y[j]),
-				col=col)
+				col=col, ...)
 	}
-	points(x, y)
+	if (points) points(x, y, ...)
 }
